@@ -620,8 +620,8 @@ gnutls_x509_crt_get_serial (gnutls_x509_crt_t cert, void *result,
 /**
   * gnutls_x509_crt_get_subject_key_id - This function returns the certificate's key identifier
   * @cert: should contain a gnutls_x509_crt_t structure
-  * @result: The place where the identifier will be copied
-  * @result_size: Holds the size of the result field.
+  * @ret: The place where the identifier will be copied
+  * @ret_size: Holds the size of the result field.
   * @critical: will be non zero if the extension is marked as critical (may be null)
   *
   * This function will return the X.509v3 certificate's subject key identifier.
@@ -985,7 +985,6 @@ gnutls_x509_crt_get_subject_alt_name (gnutls_x509_crt_t cert,
   return type;
 }
 
-
 /**
  * gnutls_x509_crt_get_basic_constraints - This function returns the certificate basic constraints
  * @cert: should contain a gnutls_x509_crt_t structure
@@ -1140,6 +1139,70 @@ gnutls_x509_crt_get_key_usage (gnutls_x509_crt_t cert,
   return 0;
 }
 
+/**
+ * gnutls_x509_crt_get_proxy - This function returns the proxy certificate info
+ * @cert: should contain a gnutls_x509_crt_t structure
+ * @critical: will be non zero if the extension is marked as critical
+ * @pathlen: pointer to output integer indicating path length (may be
+ *   NULL), non-negative values indicate a present pCPathLenConstraint
+ *   field and the actual value, -1 indicate that the field is absent.
+ *
+ * This function will read the certificate's basic constraints, and
+ * return the certificates CA status.  It reads the basicConstraints
+ * X.509 extension (2.5.29.19).
+ *
+ * Return value: If the certificate is a CA a positive value will be
+ * returned, or zero if the certificate does not have CA flag set.  A
+ * negative value may be returned in case of errors.  If the
+ * certificate does not contain the basicConstraints extension
+ * GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE will be returned.
+ **/
+int
+gnutls_x509_crt_get_proxy (gnutls_x509_crt_t cert,
+			   unsigned int *critical,
+			   int *pathlen,
+			   char **policyLanguage,
+			   char **policy,
+			   size_t *sizeof_policy)
+{
+  int result;
+  gnutls_datum_t proxyCertInfo;
+
+  if (cert == NULL)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_INVALID_REQUEST;
+    }
+
+  if ((result =
+       _gnutls_x509_crt_get_extension (cert, "1.3.6.1.5.5.7.1.14", 0,
+				       &proxyCertInfo, critical)) < 0)
+    {
+      return result;
+    }
+
+  if (proxyCertInfo.size == 0 || proxyCertInfo.data == NULL)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
+    }
+
+  result = _gnutls_x509_ext_extract_proxyCertInfo (pathlen,
+						   policyLanguage,
+						   policy,
+						   sizeof_policy,
+						   proxyCertInfo.data,
+						   proxyCertInfo.size);
+  _gnutls_free_datum (&proxyCertInfo);
+  if (result < 0)
+    {
+      gnutls_assert ();
+      return result;
+    }
+
+  return 0;
+}
+
 /**
   * gnutls_x509_crt_get_extension_by_oid - This function returns the specified extension
   * @cert: should contain a gnutls_x509_crt_t structure
